#ifndef ImaSpider_curl_wrapper_h
#define ImaSpider_curl_wrapper_h

/* Initialisation of the environment required to fetch URL
 * Returns 1 if everything went OK
 *	   0 if something went wrong
 */
int init_curl_wrapper();

/* Stores into a buffer the webpage @ url = address
 *	address is the url to fetch
 *  buffer is a pointer of a char pointer (may be unitialized, will be set by the function)
 *  size will contain the length of the buffer after the end.
 * Returns   1 if everything went OK
 *           0 is something went wrong
 */ 
int fetch_web_page(const char * address, char ** buffer, int * size);

/* Indicates if the latest requested address is text/html
 * this function is useful to prevent parsing PDF / simple text / images / movies / ...
 * Returns 	1 if everything went OK
 *	       	0 is something went wrong
 */ 
int is_latest_url_text_html();

/* Indicates the real address of the latest URL
 * this function is useful in case of redirections for instance (Apache redirs or services like t.co bit.ly...)
 * http://www.polytech-lille.fr redirects to http://www.polytech-lille.fr/ecole-d-ingenieurs.html
 *  adress will contain the actual_url (if no redirection the latest url fecthed will by provided)
 * Returns 	1 if everything went OK
 *     		0 is something went wrong
 */ 
int get_effective_url_from_latest_url(char * effective_url);

/* Cleans and closes the wrapper
 * Returns 	1 if everything went OK
 *	       	0 is something went wrong
 */ 
int close_curl_wrapper();

#endif
